{mfdeclre.i }

define shared temp-table srt no-undo
    field stPart   as character
    field stOrd    as integer
    field stln     as integer
    field stQty    as decimal
    field stSales  as decimal
    field stlOrd   as character
    index srti is primary stPart
    index s2 stSales descending  .

define temp-table tt_po
    field tp_povend like po_vend
    field tp_ponbr  like po_nbr
    field tp_poline like pod_line
    field tp_mrpqty like mrp_qty
    field tp_mrpdue_date like mrp_due_date.

/*LOCAL AND SHARED VARS*/
define variable poqty as decimal no-undo.
define variable ohqty as decimal no-undo.
define variable stdcost as decimal no-undo.
define shared variable siteList as character no-undo initial "2500,3000".
define variable qty like pt_batch label "Qty".
define variable part like ps_par.
define variable site like in_site.
define variable sseq as integer.

define variable apart like ps_par extent 30.
define variable aqty as integer extent 30 format ">>>>>>>>".
define variable vohqty like in_qty_oh.
define variable i as integer.

define buffer bptm for pt_mstr.

define new shared temp-table wf-oh no-undo
    field ohpart like ps_comp
    field ohqty like pk_qty
    index ps_comp as primary ohpart.

define new shared temp-table ck-out no-undo
    fields ckseq as integer
    fields ckpar like ps_par
    fields ckqty like pt_batch
    fields ckcomp like ps_comp
    fields ckph   like pt_phantom
    fields ckreq  like pt_batch
    fields ckum   like pt_um
    fields ckavail like in_qty_oh
    fields ckshort like in_qty_oh
    index ckseq as primary ckseq
    index ckcomp ckcomp.

sseq = 1.

part = global_part.
site = global_site.

function isSubAssembly returns logical (iPart as character):
    for first ptp_det no-lock
        where ptp_domain = global_domain
          and ptp_site = "2500"
          and ptp_part = iPart:
    end.
    if available ptp_det then do:
        if ptp_pm_code = "P" then return no.
        else return yes.
    end.
    for first pt_mstr no-lock
        where pt_domain = global_domain
          and pt_part = iPart:
    end.
    if available pt_mstr and pt_pm_code = "P" then return no.
    else return yes.
end function.

procedure explodeComponents:

    define input parameter ipPart like ps_comp no-undo.
    define input parameter iQty  as decimal no-undo.

    define query q_ps_mstr for ps_mstr .

    open query q_ps_mstr
    for each ps_mstr use-index ps_parcomp
       where ps_domain = global_domain
         and ps_par = ipPart
         and (ps_start = ? or ps_start <= today)
         and (ps_end = ?   or today <= ps_end) no-lock.
    get first q_ps_mstr no-lock.
    if not available ps_mstr then return.

    repeat while avail ps_mstr :
        /*iQty = iQty * ps_qty_per * 100 / (100 - ps_scrp_pct).*/
        {gprun.i ""xxsorp2b.p"" "(input "2500",
                                 input ps_comp,
                                 input iQty,
                                 input sseq)"}
        get next q_ps_mstr no-lock.
    end.  /* End of Repeat loop */
    close query q_ps_mstr.

end procedure.

function getOHqty returns decimal (iPart as character):
    define variable iQty as decimal no-undo.
    for each in_mstr no-lock
       where in_domain = global_domain
         and in_site = "2500"
         and in_part = iPart:
        iQty  = iQty + in_qty_oh.
    end.
    return iQty.
 end function.

function getPOqty returns decimal (iPart as character):

    define variable iQty as decimal  no-undo.
    define variable t    as character no-undo.

    empty temp-table tt_po.
    for each mrp_det no-lock
       where mrp_domain = global_domain
         and mrp_dataset = "pod_det"
         and mrp_part    = iPart,
       first po_mstr no-lock
       where po_domain = global_domain
         and po_nbr = mrp_nbr,
       first pod_det no-lock
       where pod_domain = global_domain
         and pod_nbr = po_nbr
         and pod_line  = integer(mrp_line):

        iQty  = iQty + mrp_qty.
        create tt_po.
        assign tp_povend      = po_vend
               tp_ponbr       = po_nbr
               tp_poline      = pod_line
               tp_mrpqty      = mrp_qty
               tp_mrpdue_date = mrp_due_date.
    end.
    return iQty.

end function.

function getStdCost returns decimal (iPart as character).
    define variable iQty as decimal no-undo.
    for first sct_det no-lock
        where sct_domain = global_domain
          and sct_sim  = "standard"
          and sct_part = iPart
          and lookup(sct_site, siteList) <> 0 :
        return sct_cst_tot.
    end.
    return 0.0.
 end function.

do:

  for each ck-out: delete ck-out. end.
  for each wf-oh:  delete wf-oh.  end.

    /*LOAD FGs*/
    for each srt:
/**       {mfrpchk.i}**/
       run explodeComponents
            (input stPart,
             input stQty).
    end.

    /*EXPLODE AND REMOVE SUBASSEMBLIES*/
    for each ck-out by ckseq :
/**        {mfrpchk.i}**/
        if isSubAssembly(ckcomp) then do:
            sseq = sseq + 1.
            /*DISREGARDS SUBASSEMBLIES OH*/
            run explodeComponents(input ckcomp,input ckShort).
        end.
    end.

    /*DISPLAY BLOCK*/
    form pt_prod_line   column-label "PL"
         pl_desc        column-label "PL Desc"
         ps_comp        column-label "Component"
         pt_desc1       column-label "Description"
         pt_um          column-label "UM"
         pt_batch       column-label "Demand"
         pk_qty         column-label "Avail"
         in_qty_oh      column-label "Short"
         pod_qty_rcvd   column-label "Open PO"
         po_vend        column-label "Suppluer"
         po_nbr         column-label "PO"
         pod_line       column-label "Ln"
         mrp_qty        column-label "Qty"
         mrp_due_date   column-label "Due"
         sct_cst_tot    column-label "Unit Cost"
        with down frame fcomp width 260.

    for each ck-out
   use-index ckcomp
       break by  ckcomp:

/**        {mfrpchk.i}**/

        accumulate ckShort (total by ckcomp).
        accumulate ckReq   (total by ckcomp).

        if last-of(ckcomp) and (accum total by ckcomp ckShort) > 0 then do:

            /*DISPLAY ONLY SHORTAGES*/
            for first bptm no-lock
                where bptm.pt_domain = global_domain
                  and bptm.pt_part = ckcomp:
            end.
            for first pl_mstr no-lock
                where pl_domain = global_domain
                  and pl_prod_line = bptm.pt_prod_line:
            end.

            poQty = getPOqty(ckcomp).
            ohQty = getOHqty(ckcomp).
            StdCost = getStdCost(ckcomp).

            display bptm.pt_prod_line                          @ pt_prod_line
                    if available pl_mstr then pl_desc else ""  @ pl_desc
                    ckcomp                                     @ ps_comp
                    bptm.pt_desc1                              @ pt_desc1
                    ckum                                       @ pt_um
                    (accum total by ckcomp ckreq)              @ pt_batch
                    ohQty                                      @ pk_qty
                    (accum total by ckcomp ckShort)            @ in_qty_oh
                    poqty                                      @ pod_qty_rcvd
                    StdCost                                    @ sct_cst_tot
                with down frame fcomp width 260.

            for each tt_po no-lock:
                display ckcomp         @ ps_comp
                        tp_povend      @ po_vend
                        tp_ponbr       @ po_nbr
                        tp_poline      @ pod_line
                        tp_mrpqty      @ mrp_qty
                        tp_mrpdue_date @ mrp_due_date
                    with down frame fcomp width 260.
                down 1 with frame fcomp.
            end.
            if not available tt_po then
                down 1 with frame fcomp.

        end. /* if last-of(ckcomp) and (accum total by ckcomp ckShort) > 0 */

    end. /* for each ck-out */

end.
